@@ -1,5 +1,5 @@
 import inspect
-from typing import Any, get_type_hints, Dict, Optional
+from typing import Any, get_type_hints, Dict, Optional, Tuple
 
 
 def get_annotations(implementation: Any) -> Dict[str, Any]:
@@ -19,11 +19,17 @@ def get_annotations(implementation: Any) -> Dict[str, Any]:
     return type_hints
 
 
-def get_annotations_to_implementation(implementation: Any) -> Optional[Dict[str, Any]]:
+def convert_dict_annotation_to_tuple(dict_: Dict[str, Any]) -> Tuple[Tuple[str, Any]]:
+    return tuple(((name, annotation) for name, annotation in dict_.items()))  # type: ignore
+
+
+def get_annotations_to_implementation(implementation: Any) -> Optional[Tuple[Tuple[str, Any]]]:
     if inspect.isclass(implementation):
-        return get_annotations(implementation.__init__)
+        annotations = get_annotations(implementation.__init__)
     elif inspect.isfunction(implementation) or inspect.ismethod(implementation):
-        return get_annotations(implementation)
+        annotations = get_annotations(implementation)
     elif hasattr(implementation, "__call__"):
-        return get_annotations(implementation.__call__)
-    return None
+        annotations = get_annotations(implementation.__call__)
+    else:
+        return None
+    return convert_dict_annotation_to_tuple(annotations)
