@@ -1,27 +1,44 @@
-from typing import Any, TypeVar, Type
+import inspect
+from typing import Any, TypeVar, Type, Iterable, Union, Callable, Awaitable
 import contextvars
 
 T = TypeVar("T")
 
-collection_type_names = ["Set", "List", "Tuple", "FrozenSet"]
-
 
 def _check_annotation(annotation: Any, dependency: Any) -> bool:
     try:
         if issubclass(annotation, dependency):
             return True
     except TypeError:
-        if annotation == dependency:
-            return True
+        try:
+            if isinstance(annotation, dependency):
+                return True
+        except TypeError:
+            if annotation == dependency:
+                return True
     return False
 
 
-def _is_collection_type(annotation: Any) -> bool:
+def check_generic_typing(annotation: Any, collection_type_names: Iterable[str]) -> bool:
     annotation_type_name = getattr(annotation, "_name", None)
-    if annotation_type_name is not None:
-        for collection_type_name in collection_type_names:
-            if annotation_type_name == collection_type_name:
-                return True
+    if annotation_type_name is not None and annotation_type_name in collection_type_names:
+        return True
+    return False
+
+
+def is_coroutine_callable(call: Union[Callable[..., Any], Awaitable[Any]]) -> bool:
+    if inspect.isroutine(call):
+        return inspect.iscoroutinefunction(call)
+    if inspect.isclass(call):
+        return False
+    call = getattr(call, "__call__", None)
+    return inspect.iscoroutinefunction(call)
+
+
+def check_union_typing(annotation: Any) -> bool:
+    origin = getattr(annotation, "__origin__", None)
+    if origin is not None and origin is Union:
+        return True
     return False
 
 
